@@ -11,7 +11,14 @@ from Products.Archetypes.Field import FileField
 from Products.Archetypes.Field import ObjectField
 from Products.CMFCore.utils import getToolByName
 from Acquisition import aq_parent
-    
+from Products.PloneFormGen.interfaces import IPloneFormGenActionAdapter
+
+try:
+    from Products.DataGridField import DataGridField
+except:
+    class DataGridField:
+        pass
+
 FormSaveData2ContentAdapterSchema = ATFolderSchema.copy() + FormAdapterSchema.copy() + \
     Schema((
         BooleanField('avoidSecurityChecks',
@@ -45,7 +52,7 @@ class FormSaveData2ContentAdapter(ATFolder, FormActionAdapter):
     """A form action adapter that will save form input data and 
        return it in csv- or tab-delimited format."""
 
-    implements(IFormSaveData2ContentAdapter)
+    implements(IFormSaveData2ContentAdapter, IPloneFormGenActionAdapter)
     schema = FormSaveData2ContentAdapterSchema
 
     meta_type = portal_type = 'FormSaveData2ContentAdapter'
@@ -78,6 +85,19 @@ class FormSaveData2ContentAdapter(ATFolder, FormActionAdapter):
         for field in self.fgFields():
             name = field.getName()
             value = REQUEST.form.get(name)
+            
+            if field.__class__ == DataGridField:
+                # clean up datagrid field for issues...
+                if type(value) in (tuple, set, list):
+                    newval = []
+                    for values in value:
+                        values = dict(values)
+                        if values.get('orderindex_', None) == 'template_row_marker':
+                            del values['orderindex_']
+                            
+                        newval.append(values)
+                    value = newval
+            
             if field.__class__ == FileField:
                 name += '_file'
                 if value.filename:
